Particle class

The Particle class.

Constructors

Particle({required Offset position, required Offset velocity, required double life, required Color color, required double size})
Creates a Particle instance.
Particle.atPosition(Offset pos, Random random, {List<Color>? customColors})
The atPosition property.
factory

Properties

color Color
The primary color of the border animation.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
life double
The life property.
getter/setter pair
position Offset
The position property.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
The size of the border or particle.
getter/setter pair
velocity Offset
The velocity property.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update() → void
The update property.

Operators

operator ==(Object other) bool
The equality operator.
inherited