ZoScribbleBorder class

A widget that renders ZoScribbleBorder.

Inheritance

Constructors

ZoScribbleBorder({Key? key, required Widget child, required double borderRadius, EdgeInsetsGeometry? padding, Color borderColor = Colors.green, double borderWidth = 8, double glowOpacity = 0.6, double glowSpread = 5.0, Duration animationDuration = const Duration(seconds: 4)})
Creates a ZoScribbleBorder instance.
const

Properties

animationDuration → Duration
The duration of the border animation.
final
borderColor → Color
The borderColor property.
final
borderRadius → double
The border radius of the widget.
final
borderWidth → double
The thickness of the border.
final
child → Widget
The child widget wrapped by the border.
final
glowOpacity → double
How much the border should glow min 0.1 max 1.0
final
glowSpread → double
The spread distance of the glow effect.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding → EdgeInsetsGeometry?
Empty space to surround the child.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ZoScribbleBorder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited