ZoSegmentBorder class

A widget that renders ZoSegmentBorder.

Inheritance

Constructors

ZoSegmentBorder({Key? key, required Widget child, double borderRadius = 0, List<Color>? colors, List<double>? stops, Gradient? gradient, double segmentLength = 0.15, double glowOpacity = 1.0, double glowRadius = 8.0})
Creates a ZoSegmentBorder instance.
const

Properties

borderRadius double
The border radius of the widget.
final
child Widget
The child widget wrapped by the border.
final
colors List<Color>?
The colors used in the border animation.
final
glowOpacity double
The opacity of the outer glow effect.
final
glowRadius double
The blur radius of the glow effect.
final
gradient Gradient?
The gradient used to color the border.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segmentLength double
The length of each border segment.
final
stops List<double>?
The color stops for the gradient.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ZoSegmentBorder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited