ZoTextBorder class

A widget that renders ZoTextBorder.

Inheritance

Constructors

ZoTextBorder({Key? key, required Widget child, required String text, BorderRadius borderRadius = BorderRadius.zero, double padding = 10.0, Duration duration = const Duration(seconds: 10), TextStyle textStyle = const TextStyle(color: Colors.white, fontSize: 12)})
Creates a ZoTextBorder instance.
const

Properties

borderRadius BorderRadius
The border radius of the widget.
final
child Widget
The child widget wrapped by the border.
final
duration Duration
The duration of the border animation.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding double
Empty space to surround the child.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text string displayed along the border.
final
textStyle TextStyle
The text style for the border text.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ZoTextBorder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited