Particle class

Constructors

Particle({required Offset position, required Offset velocity, required double life})
Particle.atPosition(Offset pos, Random random)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
life double
getter/setter pair
position Offset
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
velocity Offset
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited