ZoFireBorder class

A widget that renders ZoFireBorder.

Inheritance

Constructors

ZoFireBorder({Key? key, required Widget child, required Duration duration, required double borderWidth, double snakeLength = 0.1, required BorderRadius borderRadius, required Gradient gradient, List<Color>? particleColors})
Creates a ZoFireBorder instance.
const

Properties

borderRadius BorderRadius
The border radius of the widget.
final
borderWidth double
The thickness of the border.
final
child Widget
The child widget wrapped by the border.
final
duration Duration
The duration of the border animation.
final
gradient Gradient
The gradient used to color the border.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
particleColors List<Color>?
The colors of trailing particles.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snakeLength double
The relative length of the snake border segment.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ZoFireBorder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited